@@ -485,6 +485,8 @@ init_role_lookup_table (AtspiRole * role_table)
   role_table[ATK_ROLE_FOOTNOTE] = ATSPI_ROLE_FOOTNOTE;
   role_table[ATK_ROLE_CONTENT_DELETION] = ATSPI_ROLE_CONTENT_DELETION;
   role_table[ATK_ROLE_CONTENT_INSERTION] = ATSPI_ROLE_CONTENT_INSERTION;
+  role_table[ATK_ROLE_MARK] = ATSPI_ROLE_MARK;
+  role_table[ATK_ROLE_SUGGESTION] = ATSPI_ROLE_SUGGESTION;
 
   return TRUE;
 }
